=======
Credits
=======

Maintainers
-----------

- `Xiaokui Shu`_
- `Paul Coccoli`_

Contributors
------------

- `Charlie Wu`_
- `Jill Casavant`_
- `Sulakshan Vajipayajula`_
- `Chew Kin Zhong`_
- `Ian Molloy`_

.. _Xiaokui Shu: https://github.com/subbyte
.. _Paul Coccoli: https://github.com/pcoccoli
.. _Charlie Wu: https://github.com/charliewutw
.. _Jill Casavant: https://github.com/jmcasava
.. _Sulakshan Vajipayajula: https://github.com/svajipay
.. _Chew Kin Zhong: https://github.com/kinzhong
.. _Ian Molloy: https://github.com/imolloy
